==> haskell-nettle-0.2.0-17-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-nettle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: nettle
version: 0.2.0
id: nettle-0.2.0-5OQKaXi9ewv7eiuuvBHHs6
key: nettle-0.2.0-5OQKaXi9ewv7eiuuvBHHs6
license: MIT
copyright: Stefan Bühler <stbuehler@web.de>
maintainer: Stefan Bühler <stbuehler@web.de>
homepage: https://github.com/stbuehler/haskell-nettle
synopsis: safe nettle binding
description:
    safe binding for the nettle (<http://www.lysator.liu.se/~nisse/nettle/nettle.html>) library.
    Tested with 3.1.1, might work with 3.0, does NOT WORK with 2.x.
category: Cryptography
author: Stefan Bühler <stbuehler@web.de>
exposed: True
indefinite: False
exposed-modules:
    Crypto.Nettle.CCM Crypto.Nettle.ChaChaPoly1305
    Crypto.Nettle.Ciphers Crypto.Nettle.HMAC Crypto.Nettle.Hash
    Crypto.Nettle.KeyedHash Crypto.Nettle.UMAC
hidden-modules: Crypto.Nettle.Ciphers.Internal
                Crypto.Nettle.Ciphers.ForeignImports
                Crypto.Nettle.Hash.ForeignImports Crypto.Nettle.Hash.Types
                Nettle.Utils
abi: 073f247ce20a0b26e2a0fa70153d5810
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/nettle-0.2.0
library-dirs: /usr/lib/ghc-8.2.1/site-local/nettle-0.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.1/nettle-0.2.0
hs-libraries: HSnettle-0.2.0-5OQKaXi9ewv7eiuuvBHHs6
extra-libraries:
    nettle
depends:
    base-4.10.0.0 bytestring-0.10.8.2
    byteable-0.1.1-3VfNJqauCum9lD10cS8nmH
    tagged-0.8.5-7Kuk6etyDBjGPRKMYpsbFG
    securemem-0.1.9-Jq2KvPH2Mxu14cB2XfkmWp
    crypto-cipher-types-0.0.9-IMJAjxjit354Iejk8O3wjA
abi-depends: base-4.10.0.0=835a16347ec1b210054efd02671c29ee
             bytestring-0.10.8.2=590a7a3c0bdcf7a6a59d8c8ef548a44a
             byteable-0.1.1-3VfNJqauCum9lD10cS8nmH=ecad75526b40e3669fcd751d69f205cf
             tagged-0.8.5-7Kuk6etyDBjGPRKMYpsbFG=6c301deca00e1028f6b7aaf9783563bf
             securemem-0.1.9-Jq2KvPH2Mxu14cB2XfkmWp=47caf65048fddb2b140a8d8df4eaff69
             crypto-cipher-types-0.0.9-IMJAjxjit354Iejk8O3wjA=7a43d4fe3210bd7cab7fe93409272d36
haddock-interfaces: /usr/share/doc/haskell-nettle/html/nettle.haddock
haddock-html: /usr/share/doc/haskell-nettle/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-nettle-0.2.0-21-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-nettle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: nettle
version: 0.2.0
id: nettle-0.2.0-AJVtKGpcXjM6REdlSTNCPy
key: nettle-0.2.0-AJVtKGpcXjM6REdlSTNCPy
license: MIT
copyright: Stefan Bühler <stbuehler@web.de>
maintainer: Stefan Bühler <stbuehler@web.de>
homepage: https://github.com/stbuehler/haskell-nettle
synopsis: safe nettle binding
description:
    safe binding for the nettle (<http://www.lysator.liu.se/~nisse/nettle/nettle.html>) library.
    Tested with 3.1.1, might work with 3.0, does NOT WORK with 2.x.
category: Cryptography
author: Stefan Bühler <stbuehler@web.de>
exposed: True
indefinite: False
exposed-modules:
    Crypto.Nettle.CCM Crypto.Nettle.ChaChaPoly1305
    Crypto.Nettle.Ciphers Crypto.Nettle.HMAC Crypto.Nettle.Hash
    Crypto.Nettle.KeyedHash Crypto.Nettle.UMAC
hidden-modules: Crypto.Nettle.Ciphers.Internal
                Crypto.Nettle.Ciphers.ForeignImports
                Crypto.Nettle.Hash.ForeignImports Crypto.Nettle.Hash.Types
                Nettle.Utils
abi: f5077b8bbabc0f6ff7856e3cd113b00c
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/nettle-0.2.0
library-dirs: /usr/lib/ghc-8.2.1/site-local/nettle-0.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.1/nettle-0.2.0
hs-libraries: HSnettle-0.2.0-AJVtKGpcXjM6REdlSTNCPy
extra-libraries:
    nettle
depends:
    base-4.10.0.0 bytestring-0.10.8.2
    byteable-0.1.1-3VfNJqauCum9lD10cS8nmH
    tagged-0.8.5-7Kuk6etyDBjGPRKMYpsbFG
    securemem-0.1.9-5GPDBCPv82wLmZFtmA9fPE
    crypto-cipher-types-0.0.9-FlB3Fs34YAGKo4xKKfzPsc
abi-depends: base-4.10.0.0=835a16347ec1b210054efd02671c29ee
             bytestring-0.10.8.2=590a7a3c0bdcf7a6a59d8c8ef548a44a
             byteable-0.1.1-3VfNJqauCum9lD10cS8nmH=ecad75526b40e3669fcd751d69f205cf
             tagged-0.8.5-7Kuk6etyDBjGPRKMYpsbFG=6c301deca00e1028f6b7aaf9783563bf
             securemem-0.1.9-5GPDBCPv82wLmZFtmA9fPE=2a1bfce820b6c9cd60b466627f1cd95a
             crypto-cipher-types-0.0.9-FlB3Fs34YAGKo4xKKfzPsc=8530a9dfa1d9dc7f0996dca5587171b2
haddock-interfaces: /usr/share/doc/haskell-nettle/html/nettle.haddock
haddock-html: /usr/share/doc/haskell-nettle/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
